@@ -10,7 +10,7 @@ def checkIfParamExists(i: int):
     return len(sys.argv) > i and not sys.argv[i].startswith("-")
 
 
-if __name__ == "__main__":
+def main():
     try:
         isShowHelp = False
         isShowVersion = False
@@ -67,3 +67,7 @@ if __name__ == "__main__":
         print(err)
     except IndexError as indexErr:
         print(indexErr)
+
+
+if __name__ == "__main__":
+    main()
